/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.api;

import java.util.List;

import org.ow2.util.ee.metadata.common.api.interfaces.ISharedMetadata;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationResource;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationSqlDataSourceDefinition;
import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceContext;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceUnit;
import org.ow2.util.ee.metadata.common.api.struct.IJaxwsWebServiceRef;
import org.ow2.util.scan.api.metadata.IClassMetadata;

/**
 * The common interface for class metadata.
 *
 * @param <C> the common interface for class metadata
 * @param <M> the common interface for method metadata
 * @param <F> the common interface for field metadata
 *
 * @author Gael Lalire
 */
public interface ICommonClassMetadata<
    C extends ICommonClassMetadata<C, M, F>,
    M extends ICommonMethodMetadata<C, M, F>,
    F extends ICommonFieldMetadata<C, M, F>>
        extends IClassMetadata<C, M, F>, ISharedMetadata {

    /**
     * @return jEjbEJBs list representing &#64;{@link javax.ejb.EJBs}
     *         annotation.
     */
    List<IJEjbEJB> getJEjbEJBs();

    /**
     * Set JEjbEJBs object.
     *
     * @param jEjbEJBs list representing javax.ejb.EJBs annotation.
     */
    void setJEjbEJBs(final List<IJEjbEJB> jEjbEJBs);

    /**
     * @return JAnnotationResources list representing &#64;{@link javax.annotation.Resources} annotation.
     */
    List<IJAnnotationResource> getJAnnotationResources();

    /**
     * Sets JAnnotationResources object.
     *
     * @param jAnnotationResources list representing javax.annotation.Resources annotation.
     */
    void setJAnnotationResources(final List<IJAnnotationResource> jAnnotationResources);

    /**
     * @return jAnnotationSqlDataSourceDefinitions list representing &#64;{@link javax.annotation.sql.DataSourceDefinitions} annotation.
     */
    List<IJAnnotationSqlDataSourceDefinition> getJAnnotationSqlDataSourceDefinitions();

    /**
     * Sets jAnnotationSqlDataSourceDefinitions object.
     *
     * @param jAnnotationSqlDataSourceDefinitions
     *         list representing javax.annotation.sql.DataSourceDefinitions annotation.
     */
    void setJAnnotationSqlDataSourceDefinitions(final List<IJAnnotationSqlDataSourceDefinition> jAnnotationSqlDataSourceDefinitions);

    /**
     * @return javaxPersistencePersistenceContexts list representing &#64;{@link javax.persistence.PersistenceContexts}
     *         annotation.
     */
    List<IJavaxPersistenceContext> getJavaxPersistencePersistenceContexts();

    /**
     * Sets JavaxPersistencePersistenceContexts object.
     *
     * @param javaxPersistencePersistenceContexts
     *         list representing &#64;{@link javax.persistence.PersistenceContexts}
     *        annotation.
     */
    void setJavaxPersistencePersistenceContexts(final List<IJavaxPersistenceContext> javaxPersistencePersistenceContexts);

    /**
     * @return javaxPersistencePersistenceUnits list representing &#64;{@link javax.persistence.PersistenceUnits} annotation.
     */
    List<IJavaxPersistenceUnit> getJavaxPersistencePersistenceUnits();

    /**
     * Sets setJavaxPersistencePersistenceUnits object.
     *
     * @param javaxPersistencePersistenceUnits
     *         list representing &#64;{@link javax.persistence.PersistenceUnits} annotation.
     */
    void setJavaxPersistencePersistenceUnits(final List<IJavaxPersistenceUnit> javaxPersistencePersistenceUnits);

    /**
     * @return jaxwsWebServiceRefs list representing
     *         &#64;{@link javax.xml.ws.WebServiceRefs} annotation.
     */
    List<IJaxwsWebServiceRef> getJaxwsWebServiceRefs();

    /**
     * Sets jaxwsWebServiceRefs object.
     *
     * @param jaxwsWebServiceRefs list representing
     *        &#64;{@link javax.xml.ws.WebServiceRefs} annotation.
     */
    void setJaxwsWebServiceRefs(final List<IJaxwsWebServiceRef> jaxwsWebServiceRefs);

    /**
     * Set the value of the run-as property.
     *
     * @param runAs the run-as property.
     */
    void setRunAs(final String runAs);

    /**
     * @return the name of the security-role of the run-as element.
     */
    String getRunAs();

    /**
     * Set the name value of a ManagedBean.
     *
     * @param managedBeanName the ManagedBean name.
     */
    void setManagedBeanName(final String managedBeanName);

    /**
     * Returns the ManagedBean name or null if class is not annotated with @ManagedBean
     * @return the ManagedBean name or null.
     */
    String getManagedBeanName();

    /**
     * Returns true if class is not annotated with @ManagedBean
     * @return true if class is not annotated with @ManagedBean
     */
    boolean isManagedBean();
}
