/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.api.interfaces;

import java.util.Collection;
import java.util.List;
import org.ow2.util.ee.metadata.common.api.struct.IEnvEntry;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationResource;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationSqlDataSourceDefinition;
import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceContext;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceUnit;
import org.ow2.util.ee.metadata.common.api.struct.IJaxwsWebServiceRef;

/**
 * This interface provides method to keep env state.
 * @author Gael Lalire
 */
public interface IEnvironmentRefAccessor extends ISharedMetadata {

    /**
     * @return jEjbEJBs list representing &#64;{@link javax.ejb.EJBs}
     *         annotation.
     */
    List<IJEjbEJB> getJEjbEJBs();

    /**
     * Set JEjbEJBs object.
     * @param jEjbEJBs list representing javax.ejb.EJBs annotation.
     */
    void setJEjbEJBs(final List<IJEjbEJB> jEjbEJBs);

    /**
     * @return JAnnotationResources list representing &#64;{@link javax.annotation.Resources} annotation.
     */
    List<IJAnnotationResource> getJAnnotationResources();

    /**
     * Sets JAnnotationResources object.
     * @param jAnnotationResources list representing javax.annotation.Resources annotation.
     */
    void setJAnnotationResources(final List<IJAnnotationResource> jAnnotationResources);

    /**
     * @return jAnnotationSqlDataSourceDefinitions list representing &#64;{@link javax.annotation.sql
     * .DataSourceDefinitions} annotation.
     */
    List<IJAnnotationSqlDataSourceDefinition> getJAnnotationSqlDataSourceDefinitions();

    /**
     * Sets jAnnotationSqlDataSourceDefinitions object.
     *
     * @param jAnnotationSqlDataSourceDefinitions
     *         list representing javax.annotation.sql.DataSourceDefinitions annotation.
     */
    void setJAnnotationSqlDataSourceDefinitions(
            final List<IJAnnotationSqlDataSourceDefinition> jAnnotationSqlDataSourceDefinitions);

    /**
     * @return javaxPersistencePersistenceContexts list representing &#64;{@link javax.persistence.PersistenceContexts}
     *         annotation.
     */
    List<IJavaxPersistenceContext> getJavaxPersistencePersistenceContexts();

    /**
     * Sets JavaxPersistencePersistenceContexts object.
     * @param javaxPersistencePersistenceContexts list representing &#64;{@link javax.persistence.PersistenceContexts}
     *        annotation.
     */
    void setJavaxPersistencePersistenceContexts(final List<IJavaxPersistenceContext> javaxPersistencePersistenceContexts);

    /**
     * @return javaxPersistencePersistenceUnits list representing &#64;{@link javax.persistence.PersistenceUnits} annotation.
     */
    List<IJavaxPersistenceUnit> getJavaxPersistencePersistenceUnits();

    /**
     * Sets setJavaxPersistencePersistenceUnits object.
     * @param javaxPersistencePersistenceUnits list representing &#64;{@link javax.persistence.PersistenceUnits} annotation.
     */
    void setJavaxPersistencePersistenceUnits(final List<IJavaxPersistenceUnit> javaxPersistencePersistenceUnits);

    /**
     * @return jaxwsWebServiceRefs list representing &#64;{@link javax.xml.ws.WebServiceRefs} annotation.
     */
    List<IJaxwsWebServiceRef> getJaxwsWebServiceRefs();

    /**
     * Sets setJaxwsWebServiceRefs object.
     * @param jaxwsWebServiceRefs list representing &#64;{@link javax.xml.ws.WebServiceRefs} annotation.
     */
    void setJaxwsWebServiceRefs(final List<IJaxwsWebServiceRef> jaxwsWebServiceRefs);

    /**
     * @return a collection of env-entry
     */
    Collection<? extends IEnvEntry> getEnvEntryCollection();

    /**
     * @param envEntryCollection a collection of env-entry
     */
    void setEnvEntryCollection(Collection<? extends IEnvEntry> envEntryCollection);

    /**
     * @return the environment name.
     */
    String getEnvironmentName();

}
